#!/bin/bash

# Define the Salt Master address
SALT_MASTER="ingress.nixc.us"

# Step 1: Download the Salt Bootstrap Script
echo "Downloading Salt Bootstrap Script..."
curl -L https://github.com/saltstack/salt-bootstrap/releases/latest/download/bootstrap-salt.sh -o /tmp/install_salt.sh

# Step 2: Make the script executable
chmod +x /tmp/install_salt.sh

# Step 3: Run the Bootstrap Script with specified options
echo "Installing Salt Minion and configuring master..."
sh /tmp/install_salt.sh -A "$SALT_MASTER" -P -x python3 stable

# Step 4: Verify the Salt Minion Configuration
if grep -q "master: $SALT_MASTER" /etc/salt/minion; then
    echo "Salt Minion successfully configured to connect to master: $SALT_MASTER"
else
    echo "Error: Salt Minion configuration failed. Please check manually."
    exit 1
fi

# Step 5: Restart the Salt Minion service
echo "Restarting Salt Minion service..."
systemctl restart salt-minion

# Step 6: Check Salt Minion service status
echo "Checking Salt Minion service status..."
systemctl status salt-minion --no-pager

# Script completed
echo "Salt Minion setup completed."
